Clazz.declarePackage("java.net");
Clazz.load(["java.io.IOException"], "java.net.MalformedURLException", null, function(){
var c$ = Clazz.declareType(java.net, "MalformedURLException", java.io.IOException);
Clazz.makeConstructor(c$, 
function(){
Clazz.superConstructor (this, java.net.MalformedURLException, []);
});
});
;//5.0.1-v2 Thu Feb 08 09:49:36 CST 2024
